#
# spec file for package smartmontools
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           smartmontools
# Important: When doing a version update that changes DRIVEDB_BRANCH
# in smartmontools-drivedb_h-update.sh, you have to check,
# that the packaged drivedb.h has a higher svn release number than any
# version that exist in older svn branches. If not, you have
# to implement special case in the %%post section.
# Numbers in quotes are release numbers on 2013-12-04.
# http://sourceforge.net/p/smartmontools/code/HEAD/tree/branches/RELEASE_5_39_DRIVEDB/smartmontools/drivedb.h#l61 (3412)
# http://sourceforge.net/p/smartmontools/code/HEAD/tree/branches/RELEASE_5_40_DRIVEDB/smartmontools/drivedb.h#l78 (3850)
# http://sourceforge.net/p/smartmontools/code/HEAD/tree/branches/RELEASE_5_41_DRIVEDB/smartmontools/drivedb.h#l78 (3850)
# http://sourceforge.net/p/smartmontools/code/HEAD/tree/branches/RELEASE_5_43_DRIVEDB/smartmontools/drivedb.h#l78 (3850)
# http://sourceforge.net/p/smartmontools/code/HEAD/tree/branches/RELEASE_6_0_DRIVEDB/smartmontools/drivedb.h#l78 (3850)
# http://sourceforge.net/p/smartmontools/code/HEAD/tree/trunk/smartmontools/drivedb.h#l78 (3856)
Version:        6.2
Release:        5.4
Source:         http://sourceforge.net/projects/smartmontools/files/smartmontools/%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}-%{version}.tar.gz.asc
Source2:        smartmontools.sysconfig
Source3:        %{name}-rpmlintrc
Source4:        %{name}.keyring
# SOURCE-FEATURE-OPENSUSE smartmontools.generate_smartd_opts.in sbrabec@suse.cz -- sysconfig support for systemd.
Source5:        %{name}.generate_smartd_opts.in
# SOURCE-FEATURE-SLE smartmontools-drivedb_h-update.sh bnc851276 sbrabec@suse.cz -- Supplementary script to update drivedb.h.
Source6:        smartmontools-drivedb_h-update.sh
# SOURCE-FEATURE-UPSTREAM smartmontools-drivedb.h bnc851276 sbrabec@suse.cz -- Update of drivedb.h.
Source7:        smartmontools-drivedb.h
# PATCH-FEATURE-UNITEDLINUX smartmontools-default-enabled.patch sbrabec@suse.cz -- Enable smartd by default.
Patch1:         smartmontools-default-enabled.patch
# PATCH-FEATURE-OPENSUSE smartmontools-removable.patch sbrabec@suse.cz -- Skip removable devices. (bnc#308557) Report raw temperature.
Patch4:         smartmontools-removable.patch
# SUSE-FEATURE-PATCH smartmontools-nobuild-date.patch bnc#647521 pgajdos@suse.cz
Patch8:         smartmontools-nobuild-date.patch
# PATCH-FIX-OPENSUSE smartmontools-var-lock-subsys.patch sbrabec@suse.cz -- Do not use unsupported /var/lock/subsys.
Patch10:        smartmontools-var-lock-subsys.patch
# PATCH-FEATURE-OPENSUSE smartd-service-novm.patch crrodriguez@opensuse.org -- Do not start smartd in virtual environment.
Patch11:        smartd-service-novm.patch
PreReq:         %fillup_prereq
PreReq:         %insserv_prereq
# Needed by generate_smartd_opt:
PreReq:         coreutils
%if 0%{?suse_version} <= 1100
Requires:       powersave
%endif
Url:            http://smartmontools.sourceforge.net/
BuildRequires:  gcc-c++
%if 0%{?suse_version} > 1220
BuildRequires:  gpg-offline
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} >= 1110
BuildRequires:  libselinux-devel
%endif
%if 0%{?suse_version} >= 1130
BuildRequires:  libcap-ng-devel
%endif
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
Summary:        Monitor for SMART devices
License:        GPL-2.0+
Group:          Hardware/Other

%description
SMARTmontools controls and monitors storage devices using the
Self-Monitoring, Analysis, and Reporting Technology System (S.M.A.R.T.)
built into ATA, SATA and SCSI Hard Drives. This is used to check the
hard drive reliability and to predict drive failures. The suite
contains two utilities. The first, smartctl, is a command line utility
designed to perform simple S.M.A.R.T. tasks. The second, smartd, is a
daemon that periodically monitors the smart status and reports errors
to syslog. The package is compatible with the ATA/ATAPI-3 to -7
specification. The package is intended to incorporate as much "vendor
specific" and "reserved" information as possible about disk drives. The
commands man smartctl and man smartd will provide more information.

%prep
%if 0%{?gpg_verify:1}
%gpg_verify %{S:1}
%endif
%setup -q
cp -a %{SOURCE2} %{SOURCE5} .
cp -a %{SOURCE7} drivedb.h
%patch1
%patch4
%patch8 -p1
%patch10 -p1
%patch11
# PATCH-FEATURE-OPENSUSE (sed on smartd.service.in) sbrabec@suse.cz -- Use generated smartd_opts (from SUSE sysconfig file). Systemd smartd.service cannot be smart enough to parse SUSE sysconfig file and generate smartd_opts on fly. And we do not want to launch shell just for it in every boot.
sed -i "s:/usr/local/etc/sysconfig/smartmontools:%{_localstatedir}/lib/smartmontools/smartd_opts:" smartd.service.in

%build
%if 0%{?suse_version} > 1000
export CFLAGS="%{optflags} -fPIE"
export CXXFLAGS="%{optflags} -fPIE"
export LDFLAGS="-pie"
%endif
%configure\
	--with-docdir=%{_defaultdocdir}/%{name}\
%if 0%{?suse_version} >= 1110
        --with-selinux\
%endif
    --with-systemdsystemunitdir=%{_unitdir}\
	--enable-drivedb\
	--enable-savestates\
	--enable-attributelog
make %{?_smp_mflags} BUILD_INFO='"(SUSE RPM)"'
sed "s:@libdir@:%{_libdir}:g;s:@localstatedir@:%{_localstatedir}:g" <smartmontools.generate_smartd_opts.in >generate_smartd_opts

%install
%makeinstall
%if 0%{?suse_version} <= 1100 || 0%{?suse_version} > 1140
mkdir -p %{buildroot}%{_prefix}/lib/smartmontools
%endif
%if 0%{?suse_version} <= 1100
cp examplescripts/Example4 %{buildroot}%{_prefix}/lib/smartmontools/smart-notify
chmod +x %{buildroot}%{_prefix}/lib/smartmontools/smart-notify
%endif
mkdir -p %{buildroot}%{_localstatedir}/adm/fillup-templates
cp smartmontools.sysconfig %{buildroot}%{_localstatedir}/adm/fillup-templates/sysconfig.smartmontools
mkdir -p %{buildroot}%{_localstatedir}/lib/smartmontools
%if 0%{?suse_version} > 1140
touch %{buildroot}%{_localstatedir}/lib/smartmontools/smartd_opts
install generate_smartd_opts %{buildroot}%{_prefix}/lib/smartmontools/
%endif
cat >%{buildroot}%{_sysconfdir}/smart_drivedb.h <<EOF
/* smart_drivedb.h: Custom drive database. See also %{_datadir}/smartmontools/drivedb.h. */
EOF
cp smartd.service %{buildroot}/%{_unitdir}
# INSTALL file is intended only for packagers.
rm %{buildroot}%{_defaultdocdir}/%{name}/INSTALL
# Check syntax of drivedb.h that may come from a later snapshot (code from update-smart-drivedb)
if ./smartctl -B drivedb.h -P showall >/dev/null; then :; else
  echo "drivedb.h.error: rejected by smartctl, probably no longer compatible" >&2
  exit 1
fi
# Intelligent drivedb.h update, part 0.
# Check that drivedb.h has well formed svn RELEASE. We will need it for the intelligent update.
DRIVEDB_H_RELEASE_CHECK="$(sed -n 's/^.*$Id: drivedb.h \([0-9][0-9]*\) .*$/\1/p' <%{buildroot}%{_datadir}/smartmontools/drivedb.h)"
# Fail if the file has broken release number.
test "$DRIVEDB_H_RELEASE_CHECK" -ge 0

%clean
rm -rf %{buildroot}

%pre 
%service_add_pre smartd.service
# Intelligent drivedb.h update, part 1.
# Save installed drivedb.h. Maybe the sysadmin called update-smart-drivedb,
# and the installed drivedb.h may be even newer than the new packaged one.
if test -f %{_datadir}/smartmontools/drivedb.h ; then
    # Be on safe side, remove any potential drivedb.h.rpmsave.
    rm -f %{_datadir}/smartmontools/drivedb.h.rpmsave
    ln %{_datadir}/smartmontools/drivedb.h %{_datadir}/smartmontools/drivedb.h.rpmsave
fi

%post
# First prepare sysconfig.
%{fillup_only}

%if 0%{?suse_version} > 1140
# Then generate initial %{_localstatedir}/lib/smartmontools/smartd_opts needed by smartd.service.
SMARTD_SKIP_INIT=1 %{_prefix}/lib/smartmontools/generate_smartd_opts
%endif
# No start by default here.. belongs to -presets packages
%service_add_post smartd.service
# Intelligent drivedb.h update, part 2.
# Now we have the old system drivedb.h and the new packaged drivedb.h.
if test -f %{_datadir}/smartmontools/drivedb.h.rpmsave ; then
    # Compare their release numbers.
    DRIVEDB_H_RELEASE_RPM="$(sed -n 's/^.*$Id: drivedb.h \([0-9][0-9]*\) .*$/\1/p' <%{_datadir}/smartmontools/drivedb.h)"
    DRIVEDB_H_RELEASE_SAVED="$(sed -n 's/^.*$Id: drivedb.h \([0-9][0-9]*\) .*$/\1/p' <%{_datadir}/smartmontools/drivedb.h.rpmsave)"
    # File has broken release number. Skip the update.
    # Note: The SAVED release number may be broken. The test syntax must cover it.
    if test "$DRIVEDB_H_RELEASE_RPM" -lt "$DRIVEDB_H_RELEASE_SAVED" ; then
	mv %{_datadir}/smartmontools/drivedb.h.rpmsave %{_datadir}/smartmontools/drivedb.h
    else
	# Saved file is older or equal, or saved file has broken release number.
	rm %{_datadir}/smartmontools/drivedb.h.rpmsave
	# We returned to the vanilla packages, remove files created by update-smart-drivedb.
	rm -f %{_datadir}/smartmontools/drivedb.h.old %{_datadir}/smartmontools/drivedb.h.lastcheck

    fi
fi

%preun
%service_del_preun smartd.service

%postun
%service_del_postun smartd.service

%files
%defattr(-, root, root)
%doc %{_docdir}/%{name}
%dir %{_datadir}/smartmontools
%verify(not md5 size mtime) %{_datadir}/smartmontools/drivedb.h
%doc %{_mandir}/man*/*
%dir %{_localstatedir}/lib/smartmontools
%if 0%{?suse_version} > 1140
%ghost %{_localstatedir}/lib/smartmontools/smartd_opts
%endif
%if 0%{?suse_version} <= 1100 || 0%{?suse_version} > 1140
%{_prefix}/lib/smartmontools
%endif
%{_unitdir}/*
%{_sbindir}/*
%config(noreplace) %{_sysconfdir}/smart_drivedb.h
%config(noreplace) %{_sysconfdir}/smartd.conf
%config(noreplace) %{_sysconfdir}/smartd_warning.sh
%{_localstatedir}/adm/fillup-templates/sysconfig.*

%changelog
* Thu Dec  5 2013 sbrabec@suse.com
- Add supplementary drivedb.h update script
  (smartmontools-drivedb_h-update.sh, bnc#851276).
- Skip drivedb.h verification by rpm -V (bnc#851276).
- Implement intelligent drivedb.h update not overwriting newer
  drivedb.h releases.
- Update smartmontools-drivedb.h to the latest version from the
  upstream branch trunk.
* Mon Jul 29 2013 sbrabec@suse.cz
- Update to version 6.2:
  * smartctl: Added ATA write cache reordering control using
    '-g wcreorder' and '-s wcreorder,[on|off]' options.
  * update-smart-drivedb: Updated for new SVN repository.
  * HDD, SSD and USB additions to drive database.
  * Areca RAID support: Fixed possible segfault on empty port.
  * HPT RAID support: Maximum disk number increased to 128.
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Wed Apr  3 2013 crrodriguez@opensuse.org
- remove all sysvinit support.
* Mon Mar 18 2013 sbrabec@suse.cz
- Update to version 6.1:
  * smartctl -l improved.
  * smartctl -s/-g wcache and rcache for SCSI devices.
  * smartctl prints more info for ATA and SCSI devices.
  * smartctl '--identify' updated for latest ATA ACS-3 spec.
  * smartd runs /etc/smartd_warning.sh to generate warning emails.
  * smartd '-w PATH' option to specify this executable.
  * smartd '-d ignore' directive.
  * smartd DEVICESCAN ignores devices already specified.
  * smartd: added support for -s and -A for SCSI devices.
  * smartd '-W' directive uses ATA attribute 190 if 194 is missing.
  * Support of larger SCSI defect lists via READ DEFECT(12).
  * Device type '-d usbjmicron,p' for Prolific USB bridges.
  * Many HDD, SSD and USB additions to drive database.
  * Support for SAS disks behind Areca controllers.
  * Improved support for SATA disks on LSI/Megaraid controllers.
  * Disks on MegaRaid controllers are automatically scanned.
- smartmontools.keyring: New signing key for the next 2 years.
* Wed Dec 12 2012 sbrabec@suse.cz
- Use sysconfig variables (sed on smartd.service.in) and generate
  smartd_opts for systemd smartd.service.
- Remove obsolete parsing of /etc/default/smartmontools
  (it is no more in upstream installation).
* Thu Nov 29 2012 sbrabec@suse.cz
- Verify GPG signature.
* Tue Nov 20 2012 sbrabec@suse.cz
- Re-introduce smartmontools-sysconfig.patch with
  SMARTD_SAVESTATES, SMARTD_ATTRLOG and SMARTD_EXTRA_OPTS sysconfig
  variables (bnc#790044).
* Thu Nov 15 2012 sbrabec@suse.cz
- Update to version 6.0 (bnc#789204):
  * option/directive '-F nologdir' and '-F xerrorlba'.
  * smartctl '--identify' option.
  * smartctl prints nominal media rotation rate (ATA).
  * smartctl prints SATA version and speed.
  * smartctl '-l sataphy' works for CD/DVD drives also.
  * smartctl '-x' includes ATA Device Statistics.
  * smartd warning emails include device identify info.
  * smartd '-d' output is flushed to support redirection.
  * Many HDD, SSD and USB additions to drive database.
  * smartctl options '-g, --get' and '-s, --set' to get/set various
    ATA settings: AAM, APM, Read look-ahead, Write cache, Security
    (freeze), Standby mode/timer.
  * smartd directive '-e' to set (most of) the above settings on
    startup.
  * smartctl options '-f hex' and '-f hex,[id|val]'.
  * smartctl does not start ATA self-test if another test is
    already running.  Override with new option '-t force'.
  * smartctl supports extended self-test polling times greater
    than 255 minutes.
  * Controller-independent SAT detection: '-d sat,auto[+TYPE]'.
  * smartd.conf DEFAULT directive.
  * Support for SATA disks behind Areca SAS RAID controllers and
    HP Smart Array controllers.
* Tue Nov  6 2012 coolo@suse.com
- do no longer require syslog on 12.3, journal is enough for
  some installations
* Tue Sep 11 2012 coolo@suse.com
- buildrequire systemd to have working rpm macros
* Thu May 31 2012 sweet_f_a@gmx.de
- update to the _latest_ smartmontools-5.42 tarball, see
  http://sourceforge.net/mailarchive/message.php?msg_id=28262364
  "The PKG_PROG_PKG_CONFIG macro was not expanded in configure"
- remove automake dependency
* Tue Feb 21 2012 sbrabec@suse.cz
- Disable PIE for SLE9.
* Wed Nov 30 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Nov 22 2011 crrodriguez@opensuse.org
- When in a virtualized envirnment, hard disk monitoring
  with smartd is a task for the host, make systemd to skip
  the service if found running in such setup.
* Fri Oct 21 2011 sbrabec@suse.cz
- Upgrade to version 5.42 (bnc#725631):
  * smartctl option '-l devstat' (Device Statistics).
  * smartctl option '-l ssd' (SSD endurance indicator).
  * smartd logs identify information of each SCSI/SAS device.
  * smartd resends warning emails if problem reappears.
  * smartd directives '-l offlinests' and '-l selfteststs'.
  * Many HDD, SSD and USB additions to drive database.
  * Platform-specific man pages.
  * smartd.8 man page no longer includes smartd.conf.5.
  * Support for Areca controllers enhanced.
- Fixed pid file location (bnc#714647).
* Mon Oct 10 2011 bruno@ioda-net.ch
- reuse of %%makeinstall to build for SLES11_SP1-
* Sun Oct  9 2011 bruno@ioda-net.ch
- upgrade to 5.41 Date 2011-06-09
  - Failed self-tests outdated by a newer successful extended
    self-test are no longer reported as errors.
  - Support for ATA Long Logical/Physical Sectors (LLS/LPS).
  - 'smartctl --scan-open' can create a draft smartd.conf.
  - smartctl prints World Wide Name (WWN) of ATA device.
  - smartctl option '-f brief' to select new attribute output
    format which includes more flags and fits in 80 columns.
  - smartd logs identify information and WWN of each ATA device.
  - smartd logs warning from drive database if present.
  - smartd logs changes of offline data collection status.
  - smartd directive '-l scterc,READTIME,WRITETIME'.
  - smartd preserves last scheduled selective self-tests span.
  - 'smartd.service' file for systemd.
  - configure option '--with-systemdsystemunitdir'
  - configure option '--with-exampledir'.
  - configure searches for init.d or rc.d directory.
  - 'make install' does no longer overwrite an existing
    smartd.conf file.
  - 'update-smart-drivedb' does no longer require GNU sed.
  - Many HDD, SSD and USB additions to drive database.
  - Linux USB autodetection: Enable '-d sat,16' for newer kernels.
  - Linux megaraid: Fix segfault on non-data SCSI commands.
  - Linux megaraid: Fix pass-through of non-data ATA commands.
- clean up old patches included in upstream
- added systemd upstream configure option
- added patch for FSF-address
- clean up spec with spec-cleaner-
* Wed Jun  8 2011 sbrabec@suse.cz
- Added sysconfig options to set arbitrary smartd options and
  disable persistent state writes and attribute log (FATE#310460).
- Decrease log message on unsupported state writes to DEBUG
  (FATE#310460).
- Change sysconfig ServiceReload to ServiceRestart, otherwise
  sysconfig changes will not take effect until restart.
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Thu Feb  3 2011 pgajdos@suse.cz
- fixed smartctl -V command to show version [bnc#647521]
  * modified nobuild-date.patch
* Thu Jan 13 2011 sbrabec@suse.cz
- Removed support for SLE9 and older.
* Tue Dec  7 2010 coolo@novell.com
- prereq init script syslog
* Thu Oct 21 2010 ro@suse.de
- update to final 5.40
  - configure: '--enable-drivedb' is now the default.
  - Improved support for Intel SSDs.
  - Improved support for SandForce based SSDs.
  - Many additions to drive database.
  - smartctl option '-t vendor,N'.
  - Linux: Support SATA drives on LSI 3ware 9750 controllers.
  - Fix regression in smartd SMARTD_DEVICE and SMARTD_DEVICETYPE
    environment variables.
* Wed Oct  6 2010 sbrabec@suse.cz
- Added rpmlintrc.
- Removed Obsoletes for ancient packages.
- Enabled attribute log.
* Tue Sep 28 2010 cristian.rodriguez@opensuse.org
- Fix patch to remove build Dates
- Update to a newer version of 5.39.1 branch in order
  to support libcap-ng so smartd can drop privileges
* Sun Aug 29 2010 cristian.rodriguez@opensuse.org
- Do not include build enviroment infon in the binaries
  including date and time of compilation, makes build-compare
  happier.
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Wed Feb 10 2010 sbrabec@suse.cz
- Updated to version 5.39.1:
  * Fix regression in smartctl option '-q, --quietmode'.
  * Fix regression in smartd directive '-l selftest'.
  * Linux: Allow smartd 'DEVICESCAN -d sat'.
  * Linux: Fix spin-up of SATA drive if '-n standby' is used
    (bnc#576662).
  * Support for up to 128 devices on 3ware controllers
  * smartctl option '-l xerror' to print ATA SMART Extended
    Comprehensive Error Log
  * Option '-d sat+TYPE' to use SAT with controllers which require
    '-d TYPE'
  * Option '-v ID,RAW_FORMAT,ATTR_NAME' to add new vendor specific
    attributes
  * Support for SSD drives using 64-bit raw attributes
  * Many additions to drive database
  * New simplified syntax for drive database
  * Configure option to add drive database file to distribution
  * smartd can now handle attributes 197 and 198 with increasing
    raw values
  * smartd logs changes of self-test execution status
  * smartd directive '-n powermode,N' to limit the number of
    skipped checks
  * smartd flag '!' for '-r' and '-R' directives to log changes as
    critical
  * Self-tests scheduled during system downtime or disk standby are
    run after next startup (bnc#469859).
  * smartd option '-s PREFIX' to store smartd internal state until
    next startup
  * smartd option '-A PREFIX' to log attributes at each check cycle
  * Configure options to enable the above by default
  * Change to an object oriented interface to access ATA and SCSI
    devices
  * Modules migrated to new interface
  * Rework of smartd data structures
  * Checkin date and SVN revision and optional BUILD_INFO printed
    in version info
  * SELinux fixes to 3ware device node creation
  * Use getaddrinfo() instead of gethostbyname() to support IPv6
  * Additional support for Samsung MLC flash drives
* Tue Feb  9 2010 sbrabec@suse.cz
- Changed daemon start policy from "force yes" to "default start"
  (bnc#567416).
* Mon Aug 10 2009 sbrabec@suse.cz
- Updated to the latest SVN snapshot:
  * More drives recognized: Fujitsu MHW2 BJ series, WD Caviar Black
    family, Western Digital AV-GP series, Transcend Solid-State
    Drive and Transcend Solid-State Drive V series, Seagate
    Momentus 5400.5 series.
  * Fix data type bug in checksum test for multi sector logs.
  * Add USB ID of Seagate FreeAgent Go.
  * Add experimental feature to log attribute values at each check
    cycle (ATA only).
  * Heads up about a non backwardly compatible change introduced in
    draft SAT-2 (sat2r8b.pdf) that will break our existing SAT
    processing code. Action needed if change stands.
  * smartctl: Don't report an attribute as failed if threshold is
    0.
  * Print only one warning on checksum errors in multi sector log.
  * Require to specify PORT parameter of '-d usbjmicron' if two
    disks are connected.
  * smartctl: Limit default number of printed entries for '-l
    xerror' to 8, for '-l xselftest' to 25.
  * smartctl: Fix number of entries in '-l xselftest' output.
  * Add USB IDs of a SunplusIT bridge, three WD drives, and an
    unsupported Iomega drive.
  * smartd: Add '!' flag to '-r' and '-R' directives. If specified,
    message is logged as LOG_CRIT and warning mail is sent if
    attribute normalized or raw value changes.
  * Add names for some attributes used in Samsung MLC drives:
    178-180 & 183
  * smartctl: Add option '-x, --xall' to print all info including
    extended SMART logs and non-SMART info.
  * smartctl: Add '-l xerror,error' and '-l xselftest,selftest' to
    print the old logs if the extended logs are not supported.
  * Disable 48-bit ATA commands for JMicron USB bridges by default.
  * smartd: Don't ignore the '-n' directive when a self-test is
    scheduled.
  * SCSI (SAS): implement '-l sasphy,reset'.
  * SCSI (SAS): add '-l sasphy' and '-l sasphy,reset' into smartctl.
  * Print General Purpose Logs even if GPL feature bit is missing.
* Sat Jul 18 2009 dominique-obs@leuenberger.net
- bootstrap with automake-1.11
* Wed Jun  3 2009 sbrabec@suse.cz
- Updated to the latest CVS snapshot:
  * SCSI: Fetch load-unload cycle counts
  * smartd: Fix '-M test' directive in conjunction with '-s'
  * knowndrives updates
  * Add '+' modifier to smartd '-C' and '-U' directives
  * Add experimental option '-d usbsunplus' for drives behind
    SunplusIT USB bridges.
  * Add smartctl '-d test' option
  * Add experimental USB device type autodetection
  * Add new SMART STATUS check command for JMicron USB bridges
  * Add smartctl option '-l xerror[,NUM]'
  * Accept half healthy (and half unhealthy) indication from the
    SMART RETURN STATUS.
  * Workaround for huge raw values of Reallocated_Sector_Ct and
    Reallocated_Event_Ct for newer Fujitsu disks.
* Wed Feb 11 2009 sbrabec@suse.cz
- Enabled selinux support only for supported platforms.
- Removed support for SLE9 (no more compilable).
* Thu Nov 27 2008 sbrabec@suse.cz
- smartd_opts migrated to sysconfig (bnc#448205).
* Fri Oct 24 2008 sbrabec@suse.cz
- Updated to the latest CVS snapshot:
  * DEVICESCAN works again with SATA (bnc#436567)
  * knowndrives updates, now using full regexps
  * support for local drive database entries from optional file
  * support for scheduled self tests
  * smartd persistent state and delayed test scheduling support
  * support for disks behind MegaRAID controllers
  * Improve min/max temperature recording in conjunction with '-s'.
  * new options to -l
  * code cleanup and other fixes
- Init script updated to support "unused" state (bnc#436567).
- Added "rescan" to the init script to force rescanning of devices.
- Enabled selinux support to create /dev/tw[ae] with correct
  contexts.
* Tue Sep  2 2008 sbrabec@suse.cz
- Desktop neutral powersave-notify is no longer available.
  Use "wall" to report expected disc failures.
* Mon Aug 18 2008 sbrabec@suse.cz
- Updated to the latest CVS snapshot:
  * Areca device support.
  * More discs recognized.
  * Code improvements to simplify adding new platforms and devices.
* Fri May 23 2008 sbrabec@suse.cz
- Updated to the latest CVS snapshot:
  * USB Cypress device support in smartd (bnc#387094).
- Fixed help strings regarding the USB Cypress support.
- Do not report errors after disconnecting of removable discs
  (bnc#308557).
* Tue May  6 2008 sbrabec@suse.cz
- Updated to the latest CVS snapshot (bnc#387094):
  * USB Cypress device support.
  * 3ware support improvements.
* Mon Mar 10 2008 sbrabec@suse.cz
- Updated to version 5.38:
  * smartd.initd.in addition
  * On Linux, DEVICESCAN now automatically recognizes SATA devices
    behind libata, and SATA devices behind the Marvell driver.
  * On Linux, a '-d sat' or '-d marvell' is automatically added
    if libata or the marvell driver are recognized behind a SCSI
    device type
  * SAT device type + SCSI generic devices work properly with
    smartd under Linux
  * Many additions to drive database
  * Some ATA-8 updates
  * Dragonfly support
  * Fixed some ATA identity byte swap problems on big endian CPUs
  * No-fork option added to smartd
  * 3ware support for controllers with more disks (32 max)
  * Improved SMART Attribute list and descriptions
  * Fix to smartctl return codes
  * Fix to scheduled tests on Highpoint RAID controllers
  * New samsung firmware bug workaround option
  * Auto-offline and Auto-save fixed in Linux + libata
  * Solaris: better SCSI support
  * Fixed and improvements to CCISS support
  * More options for SCSI temperature monitoring and history
  * Additional command line options for selective self-tests
  * Compilation fixes for various platforms.
* Tue Oct  9 2007 sbrabec@suse.cz
- Updated to the CVS version (#326738):
  * Supports SAS discs behind CCISS RAID.
- Removed bogus patch breaking HighPoint RAID (#225639).
* Wed Aug 22 2007 sbrabec@suse.cz
- Worked around missing %%restart_on_update in older versions.
- Build correctly in older SuSE versions.
* Tue Jul 24 2007 sbrabec@suse.cz
- Updated to version 5.37:
  * Rely on general SAT code instead of Linux specific.
  * Increased max line length 128 to 256 characters.
  * Added new items into drive database.
  * Fixed inclusion of PRI?64 macros from inttypes.h.
  * Fix selective self test log revision number.
  * Compile fix for SuSE.
- Really start smartd by default on new enough kernels (#201715).
- Fixed behavior for SATA discs (#225639).
* Mon Mar  5 2007 pgajdos@suse.cz
- fixed 'array subscript is above array bounds' (#239956)
* Mon Jan 22 2007 ssommer@suse.de
- fix build for automake-0.9b
* Thu Jan 18 2007 ssommer@suse.de
- support building with automake-1.10
* Wed Oct 25 2006 sbrabec@suse.cz
- Updated to the today CVS version:
  * Supports SATA devices scanning out of the box (#201715#c9).
  * Supports SATA devices behind SCSI ATA Translation layer.
  * Supports SATA drives behind HighPoint Raid controllers.
  * Supports HP SmartArray RAID controller (cciss) (#186013).
- Updated SATA support stuff.
- Start smartd by default on new enough kernels (#201715).
* Wed Sep 13 2006 sbrabec@suse.cz
- Integrated with powersave.
- Use upstream init script.
* Thu Sep  7 2006 sbrabec@suse.cz
- Updated to version 5.36:
  * Additions to the table of known drives.
  * Works 'out of the box' with Linux SATA libata.
  * smartd option added to list test schedules.
  * smartctl option added to list part of drive database.
  * Various improvements for SCSI disks and logs.
  * Printing of drive family info.
  * SCSI disks: output size of grown defect list.
  * Added info about drive family to 'smartctl -i' output.
  * Added option ',q' for smartd '-n' directive to suppress
    'skipping checks' message which may spin up laptop disk.
  * Added message if smartd '-n' check power mode spins up disk.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jun 20 2005 ro@suse.de
- use RPM_OPT_FLAGS
- build with fPIE/pie
* Fri Mar 18 2005 sbrabec@suse.cz
- Additional information on SATA support.
* Tue Feb 22 2005 sbrabec@suse.cz
- Added comments on temperature data in smartd.conf (#50156).
* Mon Jan 24 2005 sbrabec@suse.cz
- Updated to version 5.33.
* Mon Jan  3 2005 sbrabec@suse.cz
- Fixed missing pid reference in init script (#49546).
- Updated README.SATA.
* Fri Aug 27 2004 sbrabec@suse.cz
- Updated to version 5.32.
* Sun Jun  6 2004 lmuelle@suse.de
- Update to version 5.31.
- Add stop_on_removal to preun and restart_on_update to postun.
* Sun Apr 25 2004 lmuelle@suse.de
- Add reload and condrestart to init script; [#39425].
* Mon Mar  8 2004 sbrabec@suse.cz
- Updated to version 5.30.
* Fri Mar  5 2004 sbrabec@suse.cz
- Added README.SATA.
- Added %%build section.
* Tue Mar  2 2004 sbrabec@suse.cz
- Updated to version 5.29.
* Mon Jan 12 2004 adrian@suse.de
- build as user
* Fri Jan  9 2004 mmj@suse.de
- Updated to version 5.26
* Fri Aug 22 2003 sbrabec@suse.cz
- Updated to version 5.1-18.
* Thu Aug 21 2003 sbrabec@suse.cz
- Updated to version 5.1-17.
* Mon Aug 11 2003 sbrabec@suse.cz
- Added $sendmail to X-UnitedLinux-Should-Start.
* Thu Aug  7 2003 sbrabec@suse.cz
- Updated to version 5.1.16.
* Wed May 21 2003 sbrabec@suse.cz
- Updated to version 5.1.9.
- Fixed RPM file attributes.
* Wed Mar 26 2003 sbrabec@suse.cz
- Updated to version 5.1.9.
* Mon Jan 27 2003 sbrabec@suse.cz
- Updated to version 5.1.4.
* Mon Jan 13 2003 sbrabec@suse.cz
- Updated to version 5.1.1.
* Tue Dec 10 2002 sbrabec@suse.cz
- Updated to version 5.0.49.
* Mon Nov 25 2002 sbrabec@suse.cz
- Fixed SuSE specific things in docs and manual pages.
* Mon Nov 18 2002 sbrabec@suse.cz
- New package.
